HttpServiceClient class
- Implemented types
Constructors
- HttpServiceClient(ServiceClientConfig config, {Client? httpClient})
Properties
- config → ServiceClientConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< ServiceResult< void> > -
override
-
describe(
) → ServiceClientDescription -
override
-
execute<
T> (ServiceOperation operation, {ServiceDecoder< T> ? decoder}) → Future<ServiceResult< ServiceResponse< >T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited