ServiceClientConfig class
Constructors
-
ServiceClientConfig({required String serviceId, required Uri baseUrl, required String redactedSummary, Map<
String, String> defaultHeaders = const {}, ServiceAuthProvider? authProvider, Duration? timeout, ServiceRetryPolicy? retryPolicy, String? userAgent, ServiceTelemetryHooks? telemetryHooks}) -
const
Properties
- authProvider → ServiceAuthProvider?
-
final
- baseUrl → Uri
-
final
-
defaultHeaders
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redactedSummary → String
-
final
- retryPolicy → ServiceRetryPolicy?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceId → String
-
final
- telemetryHooks → ServiceTelemetryHooks?
-
final
- timeout → Duration?
-
final
- userAgent → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited